package com.gic.store.strategy.impl;

import com.gic.spark.api.service.SparkJobApiService;
import com.gic.store.constant.StoreStatusEnum;
import com.gic.store.service.StoreLogService;
import com.gic.store.service.StoreService;
import com.gic.store.strategy.BulkUpdateStoreStrtegy;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

@Component("1")
public class StoreStatusStrategyImpl implements BulkUpdateStoreStrtegy {

    @Autowired
    private StoreLogService storeLogService;
    @Autowired
    private SparkJobApiService sparkJobApiService;

    @Override
    public int bulkUpdateStore(String storeInfoIds, Integer enterpriseId, String value, StoreService storeService, Integer operatorId, String operatorName) {
         int i = storeService.bulkUpdateStoreStatus(storeInfoIds, enterpriseId, value);
        if (i > 0) {
            List<Integer> storeInfoIdList;
            if ("all".equals(storeInfoIds)) {
                storeInfoIdList = storeService.listAllStoreInfoId(enterpriseId);
            } else {
                storeInfoIdList = new ArrayList<>();
                String[] storeIdArr = storeInfoIds.split(",");
                for (String s : storeIdArr) {
                    storeInfoIdList.add(Integer.valueOf(s));
                }
            }
            int valueCode = Integer.parseInt(value);
            storeLogService.saveBulkStoreStatusLog(storeInfoIdList, enterpriseId, operatorId, operatorName, "门店状态变更为【" + StoreStatusEnum.parseCode(valueCode) + "】");

            for (Integer storeInfoId : storeInfoIdList) {
                // 启用禁用的值和会员组取的不一致 需要转换下
                sparkJobApiService.updateStoreStatus(enterpriseId, storeInfoId, StoreStatusEnum.ONLINE.getCode() == valueCode ? 0 : 1);
            }
        }
        return i;
    }
}
